@@ -539,13 +539,21 @@ void create_context_menu (GdkEventButton *event)
                      expansion_statuses_of_subnodes.at_least_one_imd_ch_is_expanded)) || 
                     (exp_status_changes_cnt == CM_COLLAPSE && node_statuses.at_least_one_selected_node_is_expanded)) {
                     g_autofree gchar *menu_item_txt = g_strdup_printf (
-                                                                       (exp_status_changes_cnt == CM_RECURSIVELY) ? ( (number_of_selected_rows == 1) ? _("Expand Row Recursively") : _("Expand Rows Recursively") ) : 
+                                                                       (exp_status_changes_cnt == CM_RECURSIVELY) ? ( (number_of_selected_rows == 1) ? // Translation note: This is for a context menu.
+                                                                                                                                                       _("Expand Row Recursively") : 
+                                                                                                                                                       // Translation note: This is for a context menu.
+                                                                                                                                                       _("Expand Rows Recursively") ) : 
                                                                        (
-                                                                        // Translation note: "Imd. Ch. Only" means "immediate children only".
-                                                                        (exp_status_changes_cnt == CM_IMMEDIATE) ? ( (number_of_selected_rows == 1) ? _("Expand Row (Imd. Ch. Only)") : 
-                                                                        // Translation note: "Imd. Ch. Only" means "immediate children only".
+                                                                        (exp_status_changes_cnt == CM_IMMEDIATE) ? ( (number_of_selected_rows == 1) ? // Translation note: "Imd. Ch. Only" means "immediate children only".
+                                                                                                                                                      // This is for a context menu.
+                                                                                                                                                      _("Expand Row (Imd. Ch. Only)") : 
+                                                                                                                                                      // Translation note: "Imd. Ch. Only" means "immediate children only".
+                                                                                                                                                      // This is for a context menu.
                                                                                                                                                       _("Expand Rows (Imd. Ch. Only)") ) : 
-                                                                                                                    (number_of_selected_rows == 1) ? _("Collapse Row") : _("Collapse Rows")
+                                                                                                                    (number_of_selected_rows == 1) ? // This is for a context menu.
+                                                                                                                                                     _("Collapse Row") : 
+                                                                                                                                                     // This is for a context menu.
+                                                                                                                                                     _("Collapse Rows")
                                                                        )
                                                                       );
                     menu_item = gtk_menu_item_new_with_label (menu_item_txt);
